@@ -10,11 +10,13 @@ use Mockery\Adapter\Phpunit\MockeryTestCase;
 
 class TestCase extends MockeryTestCase
 {
-    /** @var Generator */
-    protected $faker;
+    /** @psalm-suppress MissingConstructor */
+    protected Generator $faker;
 
     protected function setUp(): void
     {
+        parent::setUp();
+
         $this->faker = Factory::create();
     }
 }
